import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, caleSqrt, scaleLinear, scaleTime, max, min, timeFormat, extent, histogram as bin } from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';

const width = 960;
const height = 500;
const margin = { top: 30, right: 30, bottom: 30, left: 30 };
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 45;

const App = () => {
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }

  console.log(data[0])
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const formatTime = timeFormat("%B");
  
  const xValue = d => d.DATE;
  const xAxisLabel = 'DATE';
  
  console.log(new Date("Jan"))

  const yValue = d => d.DEP_MEAN;
  const yAxisLabel = 'Avg_Delay(mins)';

  const xAxisTickFormat = timeFormat('%d %b');

  const angleScale = scaleLinear()
    .domain(d3.extent(data, xValue))
    .range([0, 2 * Math.PI]);
  

  // console.log(max(data, xValue), angleScale(max(data, xValue)))
  // console.log(min(data, xValue), angleScale(min(data, xValue)))
  // console.log(angleScale(new Date('Sat Jun 29 2018 20:00:00 GMT-0400 (EDT)')))

  const radiusScale = scaleLinear()
    .domain([0, max(data, yValue)])
    .range([170, innerHeight/2])
    .nice();
  // console.log(extent(data, yValue))
  

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${innerWidth/2 + margin.left},${innerHeight/2 + margin.top})`}>
        
        <Marks
          data={data}
          angleScale={angleScale}
          radiusScale={radiusScale}
          xValue={xValue}
          yValue={yValue}
          tooltipFormat={xAxisTickFormat}
          circleRadius={3}
        />
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
